@@ -1,5 +1,7 @@
 $(document).ready(function () {
-    $('.navbar-toggle').click(function () {
+    $('.navbar-toggle').click(function (e) {
         $('.toc > ul').toggle();
+
+        e.preventDefault();
     });
 });
